nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Srpc

Struct Srpc 

#[repr(transparent)]
pub struct Srpc(pub u32);
PhaseConfig Register

Tuple Fields

0: u32

Implementations

Source

impl Srpc

pub const fn gain_sel(&self) -> GainSel

Gain selection:

pub const fn set_gain_sel(&mut self, val: GainSel)

Gain selection:

pub const fn lock(&self) -> bool

LOCK bit to show that the internal DPLL is locked, read only

pub const fn set_lock(&mut self, val: bool)

LOCK bit to show that the internal DPLL is locked, read only

pub const fn clk_src_sel(&self) -> ClkSrcSel

Clock source selection, all other settings not shown are reserved:

pub const fn set_clk_src_sel(&mut self, val: ClkSrcSel)

Clock source selection, all other settings not shown are reserved: