nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Stc

Struct Stc 

#[repr(transparent)]
pub struct Stc(pub u32);
SPDIFTxClk Register

Tuple Fields

0: u32

Implementations

Source

impl Stc

pub const fn tx_clk_df(&self) -> TxClkDf

Divider factor (1-128)

pub const fn set_tx_clk_df(&mut self, val: TxClkDf)

Divider factor (1-128)

pub const fn tx_all_clk_en(&self) -> TxAllClkEn

Spdif transfer clock enable. When data is going to be transfered, this bit should be set to1.

pub const fn set_tx_all_clk_en(&mut self, val: TxAllClkEn)

Spdif transfer clock enable. When data is going to be transfered, this bit should be set to1.

pub const fn tx_clk_source(&self) -> TxClkSource

no description available

pub const fn set_tx_clk_source(&mut self, val: TxClkSource)

no description available

pub const fn sysclk_df(&self) -> SysclkDf

system clock divider factor, 2~512.

pub const fn set_sysclk_df(&mut self, val: SysclkDf)

system clock divider factor, 2~512.