#[repr(transparent)]pub struct Srpc(pub u32);Expand description
PhaseConfig Register
Tuple Fields
0: u32Implementations
Sourceimpl Srpc
impl Srpc
Sourcepub const fn set_gain_sel(&mut self, val: GainSel)
pub const fn set_gain_sel(&mut self, val: GainSel)
Gain selection:
Sourcepub const fn set_lock(&mut self, val: bool)
pub const fn set_lock(&mut self, val: bool)
LOCK bit to show that the internal DPLL is locked, read only
Sourcepub const fn clk_src_sel(&self) -> ClkSrcSel
pub const fn clk_src_sel(&self) -> ClkSrcSel
Clock source selection, all other settings not shown are reserved:
Sourcepub const fn set_clk_src_sel(&mut self, val: ClkSrcSel)
pub const fn set_clk_src_sel(&mut self, val: ClkSrcSel)
Clock source selection, all other settings not shown are reserved: