#[repr(transparent)]pub struct Stc(pub u32);Expand description
SPDIFTxClk Register
Tuple Fields
0: u32Implementations
Sourceimpl Stc
impl Stc
Sourcepub const fn set_tx_clk_df(&mut self, val: TxClkDf)
pub const fn set_tx_clk_df(&mut self, val: TxClkDf)
Divider factor (1-128)
Sourcepub const fn tx_all_clk_en(&self) -> TxAllClkEn
pub const fn tx_all_clk_en(&self) -> TxAllClkEn
Spdif transfer clock enable. When data is going to be transfered, this bit should be set to1.
Sourcepub const fn set_tx_all_clk_en(&mut self, val: TxAllClkEn)
pub const fn set_tx_all_clk_en(&mut self, val: TxAllClkEn)
Spdif transfer clock enable. When data is going to be transfered, this bit should be set to1.
Sourcepub const fn tx_clk_source(&self) -> TxClkSource
pub const fn tx_clk_source(&self) -> TxClkSource
no description available
Sourcepub const fn set_tx_clk_source(&mut self, val: TxClkSource)
pub const fn set_tx_clk_source(&mut self, val: TxClkSource)
no description available
Sourcepub const fn set_sysclk_df(&mut self, val: SysclkDf)
pub const fn set_sysclk_df(&mut self, val: SysclkDf)
system clock divider factor, 2~512.